@@ -1,11 +1,17 @@
-# -*- coding: utf-8 -*-
 from typing import List
 
 from chaoslib.exceptions import ActivityFailed, InterruptExecution
 
-__all__ = ["many_args", "many_args_with_rich_types", "no_args_docstring",
-           "no_args", "one_arg", "one_untyped_arg", "one_arg_with_default",
-           "one_untyped_arg_with_default"]
+__all__ = [
+    "many_args",
+    "many_args_with_rich_types",
+    "no_args_docstring",
+    "no_args",
+    "one_arg",
+    "one_untyped_arg",
+    "one_arg_with_default",
+    "one_untyped_arg_with_default",
+]
 
 
 def no_args_docstring():
@@ -26,7 +32,7 @@ def one_arg(message: str):
     pass
 
 
-def one_arg_with_default(message: str="hello"):
+def one_arg_with_default(message: str = "hello"):
     """
     One typed argument with a default value.
     """
@@ -40,14 +46,14 @@ def one_untyped_arg(message):
     pass
 
 
-def one_untyped_arg_with_default(message = "hello"):
+def one_untyped_arg_with_default(message="hello"):
     """
     One untyped argument with a default value.
     """
     pass
 
 
-def many_args(message: str, colour: str="blue"):
+def many_args(message: str, colour: str = "blue"):
     """
     Many arguments.
     """
@@ -58,10 +64,15 @@ class Whatever:
     pass
 
 
-def many_args_with_rich_types(message: str, recipients: List[str],
-                              colour: str="blue", count: int=1,
-                              logit: bool=False, other: Whatever=None,
-                              **kwargs) -> str:
+def many_args_with_rich_types(
+    message: str,
+    recipients: List[str],
+    colour: str = "blue",
+    count: int = 1,
+    logit: bool = False,
+    other: Whatever = None,
+    **kwargs
+) -> str:
     """
     Many arguments with rich types.
     """
